@@ -1,6 +1,7 @@
 # pylint: disable=unused-import
 import pytest
 import tests.helpers.constants as constants
+from tests.helpers.utils import *
 from geckordp.rdp_client import RDPClient
 from geckordp.actors.root import RootActor
 from geckordp.actors.descriptors.tab import TabActor
@@ -32,7 +33,7 @@ def test_reload():
         cl, addon, webext = init()
         val = webext.reload(
             "", 1, addon["id"])
-        assert "webExtension" in val["from"]
+        assert response_valid("webExtension", val), str(val)
     finally:
         cl.disconnect()
 
